@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display bluetooth status.
 
 Configuration parameters:
@@ -19,6 +18,9 @@ Color options:
     color_bad: No connection
     color_good: Active connection
 
+Requires:
+    pydbus: pythonic dbus library
+
 @author jmdana <https://github.com/jmdana>
 @license GPLv3 <https://www.gnu.org/licenses/gpl-3.0.txt>
 
@@ -29,18 +31,14 @@ off
 {'color': '#FF0000', 'full_text': u'BT'}
 """
 
-import dbus
+from pydbus import SystemBus
 
 DEFAULT_FORMAT = "BT[: {format_device}]"
-STRING_NOT_STARTED = "service isn't running"
 
 
 def get_connected_devices():
-    bus = dbus.SystemBus()
-    manager = dbus.Interface(
-        bus.get_object("org.bluez", "/"), "org.freedesktop.DBus.ObjectManager"
-    )
-
+    bus = SystemBus()
+    manager = bus.get("org.bluez", "/")["org.freedesktop.DBus.ObjectManager"]
     objects = manager.GetManagedObjects()
     devices = []
 
@@ -62,16 +60,16 @@ class Py3status:
     cache_timeout = 10
     format = DEFAULT_FORMAT
     format_device = "{name}"
-    format_separator = "\|"
+    format_separator = r"\|"
 
     class Meta:
         def deprecate_function(config):
             if not config.get("format_separator") and config.get("device_separator"):
                 sep = config.get("device_separator")
                 sep = sep.replace("\\", "\\\\")
-                sep = sep.replace("[", "\[")
-                sep = sep.replace("]", "\]")
-                sep = sep.replace("|", "\|")
+                sep = sep.replace("[", r"\[")
+                sep = sep.replace("]", r"\]")
+                sep = sep.replace("|", r"\|")
 
                 return {"format_separator": sep}
             else:
@@ -94,7 +92,7 @@ class Py3status:
         format_no_conn_prefix = getattr(self, "format_no_conn_prefix", None)
 
         placeholders = set(self.py3.get_placeholders_list(self.format))
-        if set(["name", "mac"]) & placeholders:
+        if {"name", "mac"} & placeholders:
             # this is an old format so should be format_device
             self.format_device = self.format
             self.format = DEFAULT_FORMAT
@@ -109,7 +107,7 @@ class Py3status:
 
         if format_prefix or format_no_conn_prefix or format_no_conn:
             # create a format that will give the expected output
-            self.format = u"[\?if=format_device {}{{format_device}}|{}{}]".format(
+            self.format = r"[\?if=format_device {}{{format_device}}|{}{}]".format(
                 format_prefix or "BT: ",
                 format_no_conn_prefix or "BT: ",
                 format_no_conn or "OFF",
@@ -119,10 +117,7 @@ class Py3status:
             self.py3.log(msg)
 
     def bluetooth(self):
-        try:
-            devices = get_connected_devices()
-        except dbus.DBusException:
-            self.py3.error(STRING_NOT_STARTED)
+        devices = get_connected_devices()
 
         if devices:
             data = []
