@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display cryptocurrency coins.
 
 The site offer various types of data such as name, symbol, price, volume,
@@ -123,7 +122,7 @@ class Py3status:
     cache_timeout = 600
     format = "{format_coin}"
     format_coin = (
-        "{name} ${price_usd:.2f} [\?color=percent_change_24h {percent_change_24h}%]"
+        r"{name} ${price_usd:.2f} [\?color=percent_change_24h {percent_change_24h}%]"
     )
     format_datetime = {}
     format_separator = " "
@@ -222,7 +221,7 @@ class Py3status:
 
         # first_use bad? the user entered bad markets. stop here (error).
         # otherwise, make a limit for first time on 1000+ coins.
-        if data and self.first_use:
+        if self.first_use:
             self.first_use = False
             if not is_equal:
                 self.py3.error("bad markets")
@@ -271,7 +270,7 @@ class Py3status:
     def coin_market(self):
         # first 1000+ coins (then %s coins)
         coin_data = self._get_coin_data()
-        if not self.limit:
+        if coin_data and not self.limit:
             # strip, compare, and maybe update again
             coin_data = self._organize_data(coin_data)
         data = self._manipulate_data(coin_data)
