@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Support i3pystatus modules in py3status.
 
@@ -7,7 +6,7 @@ py3status and provides a variety of modules. This py3status module allows
 these modules to run and be display inside py3status.
 
 Configuration parameters:
-    module: specifiy i3pystatus module to use (default None)
+    module: specify i3pystatus module to use (default None)
 
 Requires:
     i3pystatus: i3status replacement written in python
@@ -104,7 +103,7 @@ def get_backends():
             dirs = next(os.walk(os.path.join(i3pystatus_dir, subdir)))[2]
             backends.update(
                 {
-                    x[:-3]: "i3pystatus.%s.%s" % (subdir, x[:-3])
+                    x[:-3]: "i3pystatus.{}.{}".format(subdir, x[:-3])
                     for x in dirs
                     if not x.startswith("_") and x.endswith(".py")
                 }
@@ -233,9 +232,7 @@ class Py3status:
     module = None
 
     def post_config_hook(self):
-        if self.py3.is_python_2():
-            raise Exception(STRING_NOT_SUPPORTED)
-        elif not i3pystatus:
+        if not i3pystatus:
             raise Exception(STRING_NOT_INSTALLED)
         elif not self.module:
             raise Exception(STRING_MISSING_MODULE)
