@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display song/video and control MPRIS compatible players.
 
@@ -37,6 +36,7 @@ Format placeholders:
     {state} playback status of the player
     {time} played time of the song
     {title} name of the song
+    {nowplaying} now playing field provided by VLC for stream info
 
 Button placeholders:
     {next} play the next title
@@ -138,15 +138,15 @@ class Py3status:
     button_toggle = 1
     format = "[{artist} - ][{title}] {previous} {toggle} {next}"
     format_none = "no player running"
-    icon_next = u"\u25b9"
-    icon_pause = u"\u25eb"
-    icon_play = u"\u25b7"
-    icon_previous = u"\u25c3"
-    icon_stop = u"\u25a1"
+    icon_next = "\u25b9"
+    icon_pause = "\u25eb"
+    icon_play = "\u25b7"
+    icon_previous = "\u25c3"
+    icon_stop = "\u25a1"
     player_priority = []
-    state_pause = u"\u25eb"
-    state_play = u"\u25b7"
-    state_stop = u"\u25a1"
+    state_pause = "\u25eb"
+    state_play = "\u25b7"
+    state_stop = "\u25a1"
 
     def post_config_hook(self):
         if self.py3.is_gevent():
@@ -197,6 +197,7 @@ class Py3status:
             "player": None,
             "state": STOPPED,
             "title": None,
+            "nowplaying": None,
         }
 
         if self._player is None:
@@ -277,6 +278,7 @@ class Py3status:
             "length": self._data.get("length"),
             "time": ptime,
             "title": self._data.get("title") or "No Track",
+            "nowplaying": self._data.get("nowplaying"),
             "full_name": self._player_details.get("full_name"),  # for debugging ;p
         }
 
@@ -328,7 +330,7 @@ class Py3status:
     def _set_player(self):
         """
         Sort the current players into priority order and set self._player
-        Players are ordered by working state then prefernce supplied by user
+        Players are ordered by working state, then by preference supplied by user
         and finally by instance if a player has more than one running.
         """
         players = []
@@ -371,7 +373,7 @@ class Py3status:
                 player = self._mpris_players[player_id]
 
                 # Note: Workaround. Since all players get noted if playback status
-                #       has been changed we have to check if we are the choosen one
+                #       has been changed we have to check if we are the chosen one
                 try:
                     dbus_status = player["_dbus_player"].PlaybackStatus
                 except GError:
@@ -404,7 +406,7 @@ class Py3status:
             for p in self._mpris_players.values():
                 if not p["name"] and p["identity"] in self._mpris_names:
                     p["name"] = self._mpris_names[p["identity"]]
-                    p["full_name"] = u"{} {}".format(p["name"], p["index"])
+                    p["full_name"] = "{} {}".format(p["name"], p["index"])
 
         identity = player.Identity
         name = self._mpris_names.get(identity)
@@ -436,7 +438,7 @@ class Py3status:
             "index": index,
             "identity": identity,
             "name": name,
-            "full_name": u"{} {}".format(name, index),
+            "full_name": "{} {}".format(name, index),
             "status": status,
             "subscription": subscription,
         }
@@ -510,6 +512,8 @@ class Py3status:
             # delete the file extension
             self._data["title"] = re.sub(r"\....$", "", self._data.get("title"))
 
+            self._data["nowplaying"] = metadata.get("vlc:nowplaying")
+
     def kill(self):
         self._kill = True
 
@@ -556,7 +560,7 @@ class Py3status:
             "composite": composite,
         }
 
-        # we are outputing so reset tries
+        # we are outputting so reset tries
         self._tries = 0
         return response
 
